"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SequelizeDataSourceManager = void 0;
const core_1 = require("@midwayjs/core");
const sequelize_typescript_1 = require("sequelize-typescript");
let SequelizeDataSourceManager = class SequelizeDataSourceManager extends core_1.DataSourceManager {
    async init() {
        await this.initDataSource(this.sequelizeConfig, this.baseDir);
    }
    getName() {
        return 'sequelize';
    }
    async createDataSource(config, dataSourceName) {
        config.logging = (...args) => this.logger.info(args[0]);
        const client = new sequelize_typescript_1.Sequelize(config);
        const entities = config['entities'];
        if (entities && entities.length > 0) {
            client.addModels(entities);
        }
        // 兼容老写法，但是这里可能有问题，会添加到所有的数据源之中
        const listEntities = (0, core_1.listModule)('sequelize:core');
        client.addModels(listEntities);
        await client
            .authenticate()
            .then(() => {
            this.coreLogger.info({
                db: dataSourceName,
                uri: `${config.host}:${config.port}/${config.database}`,
                event: 'CONNECTED',
            });
        })
            .catch(err => {
            this.coreLogger.error({
                db: dataSourceName,
                uri: `${config.host}:${config.port}/${config.database}`,
                event: 'CONNECT FAIL',
                err,
            });
        });
        if (config.sync) {
            await client.sync();
        }
        this.coreLogger.info('[midway-plus:sequelize] %s connecting and start', dataSourceName);
        return client;
    }
    async checkConnected(dataSource) {
        try {
            await dataSource.authenticate();
            return true;
        }
        catch (err) {
            this.coreLogger.error(err);
            return false;
        }
    }
    async destroyDataSource(dataSource) {
        if (await this.checkConnected(dataSource)) {
            await dataSource.close();
        }
    }
};
__decorate([
    (0, core_1.Config)('sequelize'),
    __metadata("design:type", Object)
], SequelizeDataSourceManager.prototype, "sequelizeConfig", void 0);
__decorate([
    (0, core_1.Logger)('coreLogger'),
    __metadata("design:type", Object)
], SequelizeDataSourceManager.prototype, "coreLogger", void 0);
__decorate([
    (0, core_1.Logger)('appLogger'),
    __metadata("design:type", Object)
], SequelizeDataSourceManager.prototype, "logger", void 0);
__decorate([
    (0, core_1.Inject)(),
    __metadata("design:type", String)
], SequelizeDataSourceManager.prototype, "baseDir", void 0);
__decorate([
    (0, core_1.Init)(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], SequelizeDataSourceManager.prototype, "init", null);
SequelizeDataSourceManager = __decorate([
    (0, core_1.Provide)(),
    (0, core_1.Scope)(core_1.ScopeEnum.Singleton)
], SequelizeDataSourceManager);
exports.SequelizeDataSourceManager = SequelizeDataSourceManager;
//# sourceMappingURL=dataSourceManager.js.map